% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/FluteMLE.R
\docType{methods}
\name{FluteMLE}
\alias{FluteMLE}
\alias{flutemle}
\title{Downstream analysis based on MAGeCK-MLE result}
\usage{
FluteMLE(
  gene_summary,
  treatname,
  ctrlname = "Depmap",
  keytype = "Symbol",
  organism = "hsa",
  incorporateDepmap = FALSE,
  cell_lines = NA,
  lineages = "All",
  norm_method = "cell_cycle",
  posControl = NULL,
  omitEssential = TRUE,
  top = 10,
  toplabels = NA,
  scale_cutoff = 2,
  limit = c(0, 200),
  enrich_method = "ORT",
  proj = NA,
  width = 10,
  height = 7,
  outdir = ".",
  pathview.top = 4,
  verbose = TRUE
)
}
\arguments{
\item{gene_summary}{A data frame or a file path to gene summary file generated by MAGeCK-MLE.}

\item{treatname}{A character vector, specifying the names of treatment samples.}

\item{ctrlname}{A character vector, specifying the names of control samples.
If there is no controls in your CRISPR screen, you can specify "Depmap" as ctrlname and set `incorporateDepmap=TRUE`.}

\item{keytype}{"Entrez" or "Symbol".}

\item{organism}{"hsa" or "mmu".}

\item{incorporateDepmap}{Boolean, indicating whether incorporate Depmap data into analysis.}

\item{cell_lines}{A character vector, specifying the cell lines in Depmap to be considered.}

\item{lineages}{A character vector, specifying the lineages in Depmap to be considered.}

\item{norm_method}{One of "none", "cell_cycle" (default) or "loess".}

\item{posControl}{A character vector, specifying a list of positive control gene symbols.}

\item{omitEssential}{Boolean, indicating whether omit common essential genes from the downstream analysis.}

\item{top}{An integer, specifying the number of top selected genes to be labeled
in rank figure and the number of top pathways to be shown.}

\item{toplabels}{A character vector, specifying interested genes to be labeled in rank figure.}

\item{scale_cutoff}{Boolean or numeric, specifying how many standard deviation will be used as cutoff.}

\item{limit}{A two-length vector, specifying the minimal and maximal size of gene sets for enrichent analysis.}

\item{enrich_method}{One of "ORT"(Over-Representing Test) and "HGT"(HyperGemetric test).}

\item{proj}{A character, indicating the prefix of output file name, which can't contain special characters.}

\item{width}{The width of summary pdf in inches.}

\item{height}{The height of summary pdf in inches.}

\item{outdir}{Output directory on disk.}

\item{pathview.top}{Integer, specifying the number of pathways for pathview visualization.}

\item{verbose}{Boolean}
}
\value{
All of the pipeline results is output into the \code{out.dir}/MAGeCKFlute_\code{proj},
which includes a pdf file and many folders. The pdf file 'FluteMLE_\code{proj}_\code{norm_method}.pdf' is the
summary of pipeline results. For each section in this pipeline, figures and useful data are
outputed to corresponding subfolders.
\itemize{
  \item {QC}: {Quality control}
  \item {Selection}: {Positive selection and negative selection.}
  \item {Enrichment}: {Enrichment analysis for positive and negative selection genes.}
  \item {PathwayView}: {Pathway view for top enriched pathways.}
}
}
\description{
Integrative analysis pipeline using the gene summary table in MAGeCK MLE results
}
\details{
MAGeCK-MLE can be used to analyze screen data from multi-conditioned experiments. MAGeCK-MLE
also normalizes the data across multiple samples, making them comparable to each other. The most important
ouput of MAGeCK MLE is `gene_summary` file, which includes the beta scores of multiple conditions and
the associated statistics. The `beta score`  for each gene describes how the gene is selected: a positive
beta score indicates a positive selection, and a negative beta score indicates a negative selection.

The downstream analysis includes identifying essential, non-essential, and target-associated genes,
and performing biological functional category analysis and pathway enrichment analysis of these genes.
The function also visualizes genes in the context of pathways to benefit users exploring screening data.
}
\examples{
file3 = file.path(system.file("extdata", package = "MAGeCKFlute"),
"testdata/mle.gene_summary.txt")
\dontrun{
  # functional analysis for MAGeCK MLE results
  FluteMLE(file3, treatname = "Pmel1", ctrlname = "Pmel1_Ctrl", proj = "Pmel1")
}

}
\seealso{
\code{\link{FluteRRA}}
}
\author{
Wubing Zhang
}
